import React from "react";
import { styled } from "@mui/material/styles";
import { Dialog } from "@mui/material";
const PREFIX = "SimpleModal";

const classes = {
  paper: `${PREFIX}-paper`
};

const Root = styled("div")(({ theme }) => ({
  [`& .${classes.paper}`]: {
    position: "absolute",
    width: 400,
    backgroundColor: theme.palette.background.paper,
    border: "2px solid #000",
    boxShadow: theme.shadows[5],
    padding: theme.spacing(2, 4, 3)
  }
}));

function getModalStyle() {
  const top = 50;
  const left = 50;

  return {
    top: `${top}%`,
    left: `${left}%`,
    transform: `translate(-${top}%, -${left}%)`
  };
}

export function SimpleModal({ open, setOpen, children }) {
  // getModalStyle is not a pure function, we roll the style only on the first render
  const [modalStyle] = React.useState(getModalStyle);

  const handleClose = () => {
    setOpen(false);
  };

  return (
    <Root>
      <Dialog
        open={open}
        onClose={handleClose}
        aria-labelledby="simple-modal-title"
        aria-describedby="simple-modal-description"
      >
        <div
          style={modalStyle}
          className={classes.paper}
        >
          {children}
        </div>
      </Dialog>
    </Root>
  );
}
